pub fn set_pool(conn: DatabaseConnection) -> Result<(), DatabaseConnection>Expand description
Installs an already-open connection as the global pool (e.g. in tests).
Returns Err with the connection back if one was already installed.
pub fn set_pool(conn: DatabaseConnection) -> Result<(), DatabaseConnection>Installs an already-open connection as the global pool (e.g. in tests).
Returns Err with the connection back if one was already installed.